==> WebMSX-5.3.4.zip: WebMSX-5.3.4/src/main/room/controls/PeripheralControls.js <==
// Copyright 2015 by Paulo Augusto Peccin. See license.txt distributed with this file.

wmsx.PeripheralControls = {

    SCREEN_ASPECT_PLUS: 1, SCREEN_ASPECT_MINUS: 2,
    SCREEN_SCALE_PLUS: 3, SCREEN_SCALE_MINUS: 4,
    SCREEN_FULLSCREEN: 5,
    SCREEN_CRT_FILTER: 6, SCREEN_CRT_SCANLINES: 7, SCREEN_CRT_PHOSPHOR: 8,
    SCREEN_TOGGLE_MENU: 9,
    SCREEN_OPEN_HELP: 10,
    SCREEN_OPEN_ABOUT: 11,
    SCREEN_OPEN_SETTINGS: 12,
    SCREEN_OPEN_QUICK_OPTIONS: 13,
    SCREEN_OPEN_TOUCH_CONFIG: 14,
    SCREEN_OPEN_MACHINE_SELECT: 15,
    SCREEN_TOGGLE_VIRTUAL_KEYBOARD: 16,
    SCREEN_DEFAULTS: 17,

    SPEAKER_BUFFER_TOGGLE: 18,

    MACHINE_POWER_TOGGLE: 102, MACHINE_POWER_RESET: 103,
    MACHINE_LOAD_STATE_FILE: 104, MACHINE_SAVE_STATE_FILE: 105, MACHINE_LOAD_STATE_MENU: 106, MACHINE_SAVE_STATE_MENU: 107,
    MACHINE_SELECT: 108, EXTENSION_TOGGLE: 109,

    KEYBOARD_TOGGLE_HOST_LAYOUT: 201, JOYSTICKS_TOGGLE_MODE: 202, JOYKEYS_TOGGLE_MODE: 203, MOUSE_TOGGLE_MODE: 204, MOUSE_TOGGLE_LOCK: 205, TOUCH_TOGGLE_MODE: 206, TOUCH_TOGGLE_DIR_BIG: 207, TURBO_FIRE_TOGGLE: 208,
    HAPTIC_FEEDBACK_TOGGLE_MODE: 209,

    COPY_STRING: 301, OPEN_PASTE_STRING: 302, OPEN_ENTER_STRING: 303, CAPTURE_SCREEN: 304,

    DISK_LOAD_FILES: 20, DISK_ADD_FILES: 21, DISK_LOAD_URL: 22, DISK_LOAD_FILES_AS_DISK: 23, DISK_LOAD_ZIP_AS_DISK: 24, DISK_REMOVE: 25, DISK_EMPTY: 26, DISK_BOOT: 27, DISK_SAVE_FILE: 29,
    DISK_SELECT: 30, DISK_PREVIOUS: 31, DISK_NEXT: 32, DISK_INSERT: 33, DISK_MOVE: 34,
    HARDDISK_LOAD_FILE: 40, HARDDISK_LOAD_URL: 42, HARDDISK_LOAD_FILES_AS_DISK: 43, HARDDISK_LOAD_ZIP_AS_DISK: 44, HARDDISK_REMOVE: 45, HARDDISK_CHOOSE_EMPTY: 46, HARDDISK_CHOOSE_BOOT: 47, HARDDISK_NEW: 48, HARDDISK_SAVE_FILE: 49,
    CARTRIDGE_LOAD_FILE: 50, CARTRIDGE_LOAD_URL: 52, CARTRIDGE_REMOVE: 53, CARTRIDGE_LOAD_DATA_FILE: 54, CARTRIDGE_SAVE_DATA_FILE: 55, CARTRIDGE_CHOOSE_FORMAT: 56,
    TAPE_LOAD_FILE: 60, TAPE_LOAD_URL: 62, TAPE_REMOVE: 63, TAPE_EMPTY: 64, TAPE_SAVE_FILE: 65,
    TAPE_REWIND: 66, TAPE_TO_END: 67, TAPE_SEEK_FWD: 68, TAPE_SEEK_BACK: 69, TAPE_AUTO_RUN: 70,
    AUTO_LOAD_FILE: 80, AUTO_LOAD_URL: 81,

    SCREEN_OPEN_NETPLAY: 500

};

==> WebMSX-5.4.1.zip: WebMSX-5.4.1/src/main/room/controls/PeripheralControls.js <==
// Copyright 2015 by Paulo Augusto Peccin. See license.txt distributed with this file.

wmsx.PeripheralControls = {

    SCREEN_ASPECT_PLUS: 1, SCREEN_ASPECT_MINUS: 2,
    SCREEN_SCALE_PLUS: 3, SCREEN_SCALE_MINUS: 4,
    SCREEN_FULLSCREEN: 5,
    SCREEN_CRT_FILTER: 6, SCREEN_CRT_SCANLINES: 7, SCREEN_CRT_PHOSPHOR: 8,
    SCREEN_TOGGLE_MENU: 9,
    SCREEN_OPEN_HELP: 10,
    SCREEN_OPEN_ABOUT: 11,
    SCREEN_OPEN_SETTINGS: 12,
    SCREEN_OPEN_QUICK_OPTIONS: 13,
    SCREEN_OPEN_TOUCH_CONFIG: 14,
    SCREEN_OPEN_MACHINE_SELECT: 15,
    SCREEN_TOGGLE_VIRTUAL_KEYBOARD: 16,
    SCREEN_DEFAULTS: 17,

    SPEAKER_BUFFER_TOGGLE: 18,

    MACHINE_POWER_TOGGLE: 102, MACHINE_POWER_RESET: 103,
    MACHINE_LOAD_STATE_FILE: 104, MACHINE_SAVE_STATE_FILE: 105, MACHINE_LOAD_STATE_MENU: 106, MACHINE_SAVE_STATE_MENU: 107,
    MACHINE_SELECT: 108, EXTENSION_TOGGLE: 109,

    KEYBOARD_TOGGLE_HOST_LAYOUT: 201, JOYSTICKS_TOGGLE_MODE: 202, JOYKEYS_TOGGLE_MODE: 203, MOUSE_TOGGLE_MODE: 204, MOUSE_TOGGLE_LOCK: 205, TOUCH_TOGGLE_MODE: 206, TOUCH_TOGGLE_DIR_BIG: 207, TOUCH_TOGGLE_MIRRORED: 208,
    HAPTIC_FEEDBACK_TOGGLE_MODE: 209,

    TURBO_FIRE_TOGGLE: 210,

    COPY_STRING: 301, OPEN_PASTE_STRING: 302, OPEN_ENTER_STRING: 303, CAPTURE_SCREEN: 304,

    DISK_LOAD_FILES: 20, DISK_ADD_FILES: 21, DISK_LOAD_URL: 22, DISK_LOAD_FILES_AS_DISK: 23, DISK_LOAD_ZIP_AS_DISK: 24, DISK_REMOVE: 25, DISK_EMPTY: 26, DISK_BOOT: 27, DISK_SAVE_FILE: 29,
    DISK_SELECT: 30, DISK_PREVIOUS: 31, DISK_NEXT: 32, DISK_INSERT: 33, DISK_MOVE: 34,
    HARDDISK_LOAD_FILE: 40, HARDDISK_LOAD_URL: 42, HARDDISK_LOAD_FILES_AS_DISK: 43, HARDDISK_LOAD_ZIP_AS_DISK: 44, HARDDISK_REMOVE: 45, HARDDISK_CHOOSE_EMPTY: 46, HARDDISK_CHOOSE_BOOT: 47, HARDDISK_NEW: 48, HARDDISK_SAVE_FILE: 49,
    CARTRIDGE_LOAD_FILE: 50, CARTRIDGE_LOAD_URL: 52, CARTRIDGE_REMOVE: 53, CARTRIDGE_LOAD_DATA_FILE: 54, CARTRIDGE_SAVE_DATA_FILE: 55, CARTRIDGE_CHOOSE_FORMAT: 56,
    TAPE_LOAD_FILE: 60, TAPE_LOAD_URL: 62, TAPE_REMOVE: 63, TAPE_EMPTY: 64, TAPE_SAVE_FILE: 65,
    TAPE_REWIND: 66, TAPE_TO_END: 67, TAPE_SEEK_FWD: 68, TAPE_SEEK_BACK: 69, TAPE_AUTO_RUN: 70,
    AUTO_LOAD_FILE: 80, AUTO_LOAD_URL: 81,

    SCREEN_OPEN_NETPLAY: 500

};
